# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKPathPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkPathToImageFilterPython
else:
    import _itkPathToImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkPolyLineParametricPathPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkPointPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.itkVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkContinuousIndexPython
import itk.itkIndexPython
import itk.itkSizePython
import itk.itkOffsetPython
import itk.itkVectorContainerPython
import itk.itkArrayPython
import itk.itkParametricPathPython
import itk.itkPathBasePython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkImageRegionPython
import itk.itkImagePython
import itk.itkRGBAPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBPixelPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython

def itkPathToImageFilterPLPP2IF2_New():
    return itkPathToImageFilterPLPP2IF2.New()

class itkPathToImageFilterPLPP2IF2(itk.itkImageSourcePython.itkImageSourceIF2):
    r"""Proxy of C++ itkPathToImageFilterPLPP2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkPathToImageFilterPLPP2IF2_Pointer"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkPathToImageFilterPLPP2IF2_Pointer"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2IF2_Clone(self)

    def SetInput(self, *args):
        r"""
        SetInput(self, input)

        Parameters
        ----------
        input: itkPolyLineParametricPath2 const *

        SetInput(self, arg0, path)

        Parameters
        ----------
        arg0: unsigned int
        path: itkPolyLineParametricPath2 const *

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2IF2_SetInput(self, *args)

    def GetInput(self, *args):
        r"""
        GetInput(self) -> itkPolyLineParametricPath2
        GetInput(self, idx) -> itkPolyLineParametricPath2

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2IF2_GetInput(self, *args)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, spacing)

        Parameters
        ----------
        spacing: double const *

        SetSpacing(self, spacing)

        Parameters
        ----------
        spacing: float const *

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2IF2_SetSpacing(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> double const *"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2IF2_GetSpacing(self)

    def SetPathValue(self, _arg):
        r"""
        SetPathValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2IF2_SetPathValue(self, _arg)

    def GetPathValue(self):
        r"""GetPathValue(self) -> float"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2IF2_GetPathValue(self)

    def SetBackgroundValue(self, _arg):
        r"""
        SetBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2IF2_SetBackgroundValue(self, _arg)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> float"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2IF2_GetBackgroundValue(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, origin)

        Parameters
        ----------
        origin: double const *

        SetOrigin(self, origin)

        Parameters
        ----------
        origin: float const *

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2IF2_SetOrigin(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> double const *"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2IF2_GetOrigin(self)

    def SetSize(self, _arg):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize2

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2IF2_SetSize(self, _arg)

    def GetSize(self):
        r"""GetSize(self) -> itkSize2"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2IF2_GetSize(self)
    __swig_destroy__ = _itkPathToImageFilterPython.delete_itkPathToImageFilterPLPP2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPathToImageFilterPLPP2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkPathToImageFilterPLPP2IF2

        Create a new object of the class itkPathToImageFilterPLPP2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkPathToImageFilterPLPP2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkPathToImageFilterPLPP2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkPathToImageFilterPLPP2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkPathToImageFilterPLPP2IF2 in _itkPathToImageFilterPython:
_itkPathToImageFilterPython.itkPathToImageFilterPLPP2IF2_swigregister(itkPathToImageFilterPLPP2IF2)

def itkPathToImageFilterPLPP2ISS2_New():
    return itkPathToImageFilterPLPP2ISS2.New()

class itkPathToImageFilterPLPP2ISS2(itk.itkImageSourcePython.itkImageSourceISS2):
    r"""Proxy of C++ itkPathToImageFilterPLPP2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkPathToImageFilterPLPP2ISS2_Pointer"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkPathToImageFilterPLPP2ISS2_Pointer"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2ISS2_Clone(self)

    def SetInput(self, *args):
        r"""
        SetInput(self, input)

        Parameters
        ----------
        input: itkPolyLineParametricPath2 const *

        SetInput(self, arg0, path)

        Parameters
        ----------
        arg0: unsigned int
        path: itkPolyLineParametricPath2 const *

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2ISS2_SetInput(self, *args)

    def GetInput(self, *args):
        r"""
        GetInput(self) -> itkPolyLineParametricPath2
        GetInput(self, idx) -> itkPolyLineParametricPath2

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2ISS2_GetInput(self, *args)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, spacing)

        Parameters
        ----------
        spacing: double const *

        SetSpacing(self, spacing)

        Parameters
        ----------
        spacing: float const *

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2ISS2_SetSpacing(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> double const *"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2ISS2_GetSpacing(self)

    def SetPathValue(self, _arg):
        r"""
        SetPathValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2ISS2_SetPathValue(self, _arg)

    def GetPathValue(self):
        r"""GetPathValue(self) -> short"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2ISS2_GetPathValue(self)

    def SetBackgroundValue(self, _arg):
        r"""
        SetBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2ISS2_SetBackgroundValue(self, _arg)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> short"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2ISS2_GetBackgroundValue(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, origin)

        Parameters
        ----------
        origin: double const *

        SetOrigin(self, origin)

        Parameters
        ----------
        origin: float const *

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2ISS2_SetOrigin(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> double const *"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2ISS2_GetOrigin(self)

    def SetSize(self, _arg):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize2

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2ISS2_SetSize(self, _arg)

    def GetSize(self):
        r"""GetSize(self) -> itkSize2"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2ISS2_GetSize(self)
    __swig_destroy__ = _itkPathToImageFilterPython.delete_itkPathToImageFilterPLPP2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPathToImageFilterPLPP2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkPathToImageFilterPLPP2ISS2

        Create a new object of the class itkPathToImageFilterPLPP2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkPathToImageFilterPLPP2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkPathToImageFilterPLPP2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkPathToImageFilterPLPP2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkPathToImageFilterPLPP2ISS2 in _itkPathToImageFilterPython:
_itkPathToImageFilterPython.itkPathToImageFilterPLPP2ISS2_swigregister(itkPathToImageFilterPLPP2ISS2)

def itkPathToImageFilterPLPP2IUC2_New():
    return itkPathToImageFilterPLPP2IUC2.New()

class itkPathToImageFilterPLPP2IUC2(itk.itkImageSourcePython.itkImageSourceIUC2):
    r"""Proxy of C++ itkPathToImageFilterPLPP2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkPathToImageFilterPLPP2IUC2_Pointer"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkPathToImageFilterPLPP2IUC2_Pointer"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2IUC2_Clone(self)

    def SetInput(self, *args):
        r"""
        SetInput(self, input)

        Parameters
        ----------
        input: itkPolyLineParametricPath2 const *

        SetInput(self, arg0, path)

        Parameters
        ----------
        arg0: unsigned int
        path: itkPolyLineParametricPath2 const *

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2IUC2_SetInput(self, *args)

    def GetInput(self, *args):
        r"""
        GetInput(self) -> itkPolyLineParametricPath2
        GetInput(self, idx) -> itkPolyLineParametricPath2

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2IUC2_GetInput(self, *args)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, spacing)

        Parameters
        ----------
        spacing: double const *

        SetSpacing(self, spacing)

        Parameters
        ----------
        spacing: float const *

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2IUC2_SetSpacing(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> double const *"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2IUC2_GetSpacing(self)

    def SetPathValue(self, _arg):
        r"""
        SetPathValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2IUC2_SetPathValue(self, _arg)

    def GetPathValue(self):
        r"""GetPathValue(self) -> unsigned char"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2IUC2_GetPathValue(self)

    def SetBackgroundValue(self, _arg):
        r"""
        SetBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2IUC2_SetBackgroundValue(self, _arg)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> unsigned char"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2IUC2_GetBackgroundValue(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, origin)

        Parameters
        ----------
        origin: double const *

        SetOrigin(self, origin)

        Parameters
        ----------
        origin: float const *

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2IUC2_SetOrigin(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> double const *"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2IUC2_GetOrigin(self)

    def SetSize(self, _arg):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize2

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2IUC2_SetSize(self, _arg)

    def GetSize(self):
        r"""GetSize(self) -> itkSize2"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2IUC2_GetSize(self)
    __swig_destroy__ = _itkPathToImageFilterPython.delete_itkPathToImageFilterPLPP2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPathToImageFilterPLPP2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkPathToImageFilterPLPP2IUC2

        Create a new object of the class itkPathToImageFilterPLPP2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkPathToImageFilterPLPP2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkPathToImageFilterPLPP2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkPathToImageFilterPLPP2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkPathToImageFilterPLPP2IUC2 in _itkPathToImageFilterPython:
_itkPathToImageFilterPython.itkPathToImageFilterPLPP2IUC2_swigregister(itkPathToImageFilterPLPP2IUC2)

def itkPathToImageFilterPLPP3IF3_New():
    return itkPathToImageFilterPLPP3IF3.New()

class itkPathToImageFilterPLPP3IF3(itk.itkImageSourcePython.itkImageSourceIF3):
    r"""Proxy of C++ itkPathToImageFilterPLPP3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkPathToImageFilterPLPP3IF3_Pointer"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkPathToImageFilterPLPP3IF3_Pointer"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3IF3_Clone(self)

    def SetInput(self, *args):
        r"""
        SetInput(self, input)

        Parameters
        ----------
        input: itkPolyLineParametricPath3 const *

        SetInput(self, arg0, path)

        Parameters
        ----------
        arg0: unsigned int
        path: itkPolyLineParametricPath3 const *

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3IF3_SetInput(self, *args)

    def GetInput(self, *args):
        r"""
        GetInput(self) -> itkPolyLineParametricPath3
        GetInput(self, idx) -> itkPolyLineParametricPath3

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3IF3_GetInput(self, *args)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, spacing)

        Parameters
        ----------
        spacing: double const *

        SetSpacing(self, spacing)

        Parameters
        ----------
        spacing: float const *

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3IF3_SetSpacing(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> double const *"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3IF3_GetSpacing(self)

    def SetPathValue(self, _arg):
        r"""
        SetPathValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3IF3_SetPathValue(self, _arg)

    def GetPathValue(self):
        r"""GetPathValue(self) -> float"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3IF3_GetPathValue(self)

    def SetBackgroundValue(self, _arg):
        r"""
        SetBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3IF3_SetBackgroundValue(self, _arg)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> float"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3IF3_GetBackgroundValue(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, origin)

        Parameters
        ----------
        origin: double const *

        SetOrigin(self, origin)

        Parameters
        ----------
        origin: float const *

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3IF3_SetOrigin(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> double const *"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3IF3_GetOrigin(self)

    def SetSize(self, _arg):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize3

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3IF3_SetSize(self, _arg)

    def GetSize(self):
        r"""GetSize(self) -> itkSize3"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3IF3_GetSize(self)
    __swig_destroy__ = _itkPathToImageFilterPython.delete_itkPathToImageFilterPLPP3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPathToImageFilterPLPP3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkPathToImageFilterPLPP3IF3

        Create a new object of the class itkPathToImageFilterPLPP3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkPathToImageFilterPLPP3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkPathToImageFilterPLPP3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkPathToImageFilterPLPP3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkPathToImageFilterPLPP3IF3 in _itkPathToImageFilterPython:
_itkPathToImageFilterPython.itkPathToImageFilterPLPP3IF3_swigregister(itkPathToImageFilterPLPP3IF3)

def itkPathToImageFilterPLPP3ISS3_New():
    return itkPathToImageFilterPLPP3ISS3.New()

class itkPathToImageFilterPLPP3ISS3(itk.itkImageSourcePython.itkImageSourceISS3):
    r"""Proxy of C++ itkPathToImageFilterPLPP3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkPathToImageFilterPLPP3ISS3_Pointer"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkPathToImageFilterPLPP3ISS3_Pointer"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3ISS3_Clone(self)

    def SetInput(self, *args):
        r"""
        SetInput(self, input)

        Parameters
        ----------
        input: itkPolyLineParametricPath3 const *

        SetInput(self, arg0, path)

        Parameters
        ----------
        arg0: unsigned int
        path: itkPolyLineParametricPath3 const *

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3ISS3_SetInput(self, *args)

    def GetInput(self, *args):
        r"""
        GetInput(self) -> itkPolyLineParametricPath3
        GetInput(self, idx) -> itkPolyLineParametricPath3

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3ISS3_GetInput(self, *args)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, spacing)

        Parameters
        ----------
        spacing: double const *

        SetSpacing(self, spacing)

        Parameters
        ----------
        spacing: float const *

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3ISS3_SetSpacing(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> double const *"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3ISS3_GetSpacing(self)

    def SetPathValue(self, _arg):
        r"""
        SetPathValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3ISS3_SetPathValue(self, _arg)

    def GetPathValue(self):
        r"""GetPathValue(self) -> short"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3ISS3_GetPathValue(self)

    def SetBackgroundValue(self, _arg):
        r"""
        SetBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3ISS3_SetBackgroundValue(self, _arg)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> short"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3ISS3_GetBackgroundValue(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, origin)

        Parameters
        ----------
        origin: double const *

        SetOrigin(self, origin)

        Parameters
        ----------
        origin: float const *

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3ISS3_SetOrigin(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> double const *"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3ISS3_GetOrigin(self)

    def SetSize(self, _arg):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize3

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3ISS3_SetSize(self, _arg)

    def GetSize(self):
        r"""GetSize(self) -> itkSize3"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3ISS3_GetSize(self)
    __swig_destroy__ = _itkPathToImageFilterPython.delete_itkPathToImageFilterPLPP3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPathToImageFilterPLPP3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkPathToImageFilterPLPP3ISS3

        Create a new object of the class itkPathToImageFilterPLPP3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkPathToImageFilterPLPP3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkPathToImageFilterPLPP3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkPathToImageFilterPLPP3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkPathToImageFilterPLPP3ISS3 in _itkPathToImageFilterPython:
_itkPathToImageFilterPython.itkPathToImageFilterPLPP3ISS3_swigregister(itkPathToImageFilterPLPP3ISS3)

def itkPathToImageFilterPLPP3IUC3_New():
    return itkPathToImageFilterPLPP3IUC3.New()

class itkPathToImageFilterPLPP3IUC3(itk.itkImageSourcePython.itkImageSourceIUC3):
    r"""Proxy of C++ itkPathToImageFilterPLPP3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkPathToImageFilterPLPP3IUC3_Pointer"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkPathToImageFilterPLPP3IUC3_Pointer"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3IUC3_Clone(self)

    def SetInput(self, *args):
        r"""
        SetInput(self, input)

        Parameters
        ----------
        input: itkPolyLineParametricPath3 const *

        SetInput(self, arg0, path)

        Parameters
        ----------
        arg0: unsigned int
        path: itkPolyLineParametricPath3 const *

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3IUC3_SetInput(self, *args)

    def GetInput(self, *args):
        r"""
        GetInput(self) -> itkPolyLineParametricPath3
        GetInput(self, idx) -> itkPolyLineParametricPath3

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3IUC3_GetInput(self, *args)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, spacing)

        Parameters
        ----------
        spacing: double const *

        SetSpacing(self, spacing)

        Parameters
        ----------
        spacing: float const *

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3IUC3_SetSpacing(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> double const *"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3IUC3_GetSpacing(self)

    def SetPathValue(self, _arg):
        r"""
        SetPathValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3IUC3_SetPathValue(self, _arg)

    def GetPathValue(self):
        r"""GetPathValue(self) -> unsigned char"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3IUC3_GetPathValue(self)

    def SetBackgroundValue(self, _arg):
        r"""
        SetBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3IUC3_SetBackgroundValue(self, _arg)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> unsigned char"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3IUC3_GetBackgroundValue(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, origin)

        Parameters
        ----------
        origin: double const *

        SetOrigin(self, origin)

        Parameters
        ----------
        origin: float const *

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3IUC3_SetOrigin(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> double const *"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3IUC3_GetOrigin(self)

    def SetSize(self, _arg):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize3

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3IUC3_SetSize(self, _arg)

    def GetSize(self):
        r"""GetSize(self) -> itkSize3"""
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3IUC3_GetSize(self)
    __swig_destroy__ = _itkPathToImageFilterPython.delete_itkPathToImageFilterPLPP3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPathToImageFilterPLPP3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPathToImageFilterPython.itkPathToImageFilterPLPP3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkPathToImageFilterPLPP3IUC3

        Create a new object of the class itkPathToImageFilterPLPP3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkPathToImageFilterPLPP3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkPathToImageFilterPLPP3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkPathToImageFilterPLPP3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkPathToImageFilterPLPP3IUC3 in _itkPathToImageFilterPython:
_itkPathToImageFilterPython.itkPathToImageFilterPLPP3IUC3_swigregister(itkPathToImageFilterPLPP3IUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def path_to_image_filter(*args,  spacing=..., path_value: float=..., background_value: float=..., origin=..., size: Sequence[int]=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for PathToImageFilter"""
    import itk

    kwarg_typehints = { 'spacing':spacing,'path_value':path_value,'background_value':background_value,'origin':origin,'size':size }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.PathToImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def path_to_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKPath.PathToImageFilter
    path_to_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    path_to_image_filter.__doc__ = filter_object.__doc__



